@@ -156,7 +156,7 @@ where {dt_clause}
 order by {','.join(table.duplicate_fields)}
         """
 
-        df = wr.athena.read_sql_query(sql=sql, database=table.database.name)
+        df = wr.athena.read_sql_query(sql=sql, database=table.database.name, ctas_approach=False)
         if df.empty:
             return
 
@@ -179,6 +179,9 @@ order by {','.join(table.duplicate_fields)}
                     p = batch.iloc[0]['$path']
                     print(f'Filtering {p}')
                     f = wr.s3.read_parquet(path=p)
+                    if 'updated_on' not in f:
+                        self.info('No updated_on field in record set')
+                        continue
                     f['u'] = f['updated_on'].astype('datetime64[s]')
                     f = pd.merge(f, batch, indicator=True, how='outer', left_on=join_fields, right_on=join_fields)\
                         .query('_merge == "left_only"')\
@@ -265,13 +268,16 @@ order by {','.join(table.duplicate_fields)}
         )
         ret = []
         total = master_record_size
-        for f in response['Contents']:
-            if '.dat.snappy.parquet' in f['Key']:
-                continue
-            total += f['Size']
-            ret.append(f's3://{bucket}/{f["Key"]}')
-            if total > MAX_FILE_SIZE:
-                break
+        try:
+            for f in response['Contents']:
+                if '.dat.snappy.parquet' in f['Key']:
+                    continue
+                total += f['Size']
+                ret.append(f's3://{bucket}/{f["Key"]}')
+                if total > MAX_FILE_SIZE:
+                    break
+        except KeyError:
+            pass
 
         return ret
 
